
####################
advanced_module_name
####################

.. module:: advanced_module_name

   This is a more advanced usage of a module
   doc comment. A call to `function()` immediately
   follows this comment but because of the `@module` directive
   this comment is not considered a doccomment on the `function()`
   call. This file also sets the module name to `advanced_module_name`
   instead of allowing it to be autogenerated.
   


.. function:: test_func(param1)

   

